//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Types/VectorWC.h
//! @brief     Defines and implements templated class VectorWC.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_BASE_TYPES_VECTORWC_H
#define BORNAGAIN_BASE_TYPES_VECTORWC_H

#include "Base/Types/OwningVector.h"

//! An OwningVector with a current index.

template <class T> class VectorWC : public OwningVector<T> {
public:

    void setCurrentIndex(size_t i)
	{
	    ASSERT(i < OwningVector<T>::size() || i == -1);
	    m_current_index = i;
	}
    size_t currentIndex() const { return m_current_index; }

private:
    size_t m_current_index = -1;
};

#endif // BORNAGAIN_BASE_TYPES_VECTORWC_H
